Plateo
======

Plateo (pronounced *Plato*, like the planet) is a Python library to assist in the
planning, running and checking of laboratory experiments involving microplates.

It can be used to:

- Read and write robotic protocols (picklists) in different formats to
  accomodate different liquid dispensers (Tecan EVO, Labcyte Echo).
- Simulate liquid dispensing runs, taking into account the capacity and dead
  volume of each container, to predict the maps of future plates.
- Parse plate data from common laboratory robots (for kinetic experiments,
  fragment analysis, qPCR, etc.)
- Export plate information in various formats (graphics, spreadsheets, HTML,
  JSON, etc.).


Infos
-----

**PIP installation:**

.. code:: bash

  pip install plateo

**Web documentation:**

`<https://edinburgh-genome-foundry.github.io/Plateo/>`_

**Github Page:**

`<https://github.com/Edinburgh-Genome-Foundry/Plateo>`_

**Live demo:**

`<https://cuba.genomefoundry.org/create_assembly_picklists>`_

**License:** MIT, Copyright Edinburgh Genome Foundry


More biology software
---------------------

.. image:: https://raw.githubusercontent.com/Edinburgh-Genome-Foundry/Edinburgh-Genome-Foundry.github.io/master/static/imgs/logos/egf-codon-horizontal.png
  :target: https://edinburgh-genome-foundry.github.io/

Plateo is part of the `EGF Codons <https://edinburgh-genome-foundry.github.io/>`_ synthetic biology software suite for DNA design, manufacturing and validation.
